---
Summary: `sbl -b` gives blank output
Status: Done
---

# Description

`sbl -b` is supposed to provide the filenames of all cards in a collection
without headings per [[cli017]]. It doesn't any more.

Only requirement is that [[cli017]] works again.
